@@ -80,7 +80,9 @@ class AlgebraicModule:
             warnings.warn(f"Function arity does not match args of {self.name}")
 
     def _check_dynamic_variables(self) -> None:
-        difference = set(self.dynamic_variables).difference(self.compounds + self.modifiers)
+        difference = set(self.dynamic_variables).difference(
+            self.compounds + self.modifiers
+        )
         if difference:
             warnings.warn(
                 f"Supplied args {difference} for module {self.name} that aren't in compounds or modifiers"
@@ -135,7 +137,9 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
     compounds that are calculated before the rate functions are calculated.
     """
 
-    def __init__(self, algebraic_modules: Optional[Dict[str, Dict[str, Any]]] = None) -> None:
+    def __init__(
+        self, algebraic_modules: Optional[Dict[str, Dict[str, Any]]] = None
+    ) -> None:
         self.algebraic_modules: Dict[str, AlgebraicModule] = {}
         self._algebraic_module_order: List[str] = []
         if algebraic_modules is not None:
@@ -207,7 +211,9 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
                 )
         self._algebraic_module_order = module_order
 
-    def _check_module_consistency(self, module: AlgebraicModule, check_ids: bool = True) -> None:
+    def _check_module_consistency(
+        self, module: AlgebraicModule, check_ids: bool = True
+    ) -> None:
         self._check_for_existence(
             name=module.name,
             check_against=self.get_all_compounds(),
@@ -340,7 +346,9 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
             sort_modules=sort_modules,
         )
 
-    def add_algebraic_modules(self, algebraic_modules: dict, meta_info: dict | None = None) -> None:
+    def add_algebraic_modules(
+        self, algebraic_modules: dict, meta_info: dict | None = None
+    ) -> None:
         """Add multiple algebraic modules to the model.
 
         See Also
@@ -355,7 +363,8 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
     def update_algebraic_module(
         self,
         module_name: str,
-        function: Union[Callable[..., float], Callable[..., Iterable[float]]] | None = None,
+        function: Union[Callable[..., float], Callable[..., Iterable[float]]]
+        | None = None,
         compounds: List[str] | None = None,
         derived_compounds: List[str] | None = None,
         modifiers: List[str] | None = None,
@@ -421,6 +430,18 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
         if sort_modules:
             self._sort_algebraic_modules()
 
+    def update_algebraic_module_from_args(
+        self,
+        module_name: str,
+        function: Union[Callable[..., float], Callable[..., Iterable[float]]]
+        | None = None,
+        derived_compounds: List[str] | None = None,
+        args: List[str] | None = None,
+        check_consistency: bool | None = None,
+        sort_modules: bool | None = None,
+    ) -> None:
+        raise NotImplementedError
+
     def update_algebraic_modules(self, modules: dict) -> None:
         """Update multiple algebraic modules
 
@@ -444,7 +465,9 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
         """
         self.update_meta_info(component="modules", meta_info={module: meta_info})
 
-    def remove_algebraic_module(self, module_name: str, sort_modules: bool = True) -> None:
+    def remove_algebraic_module(
+        self, module_name: str, sort_modules: bool = True
+    ) -> None:
         """Remove an algebraic module.
 
         Parameters
@@ -518,7 +541,8 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
         y["time"] = t
         # args = self.parameters | y # that is python 3.9+ syntax, wait for a bit
         args: Dict[str, Union[float, Array]] = {**self.parameters, **y}
-        for name, module in self.algebraic_modules.items():
+        for name in self._algebraic_module_order:
+            module = self.algebraic_modules[name]
             try:
                 derived_values = module.function(*(args[arg] for arg in module.args))
             except KeyError as e:
@@ -537,7 +561,9 @@ class AlgebraicMixin(ParameterMixin, CompoundMixin, BaseModel):
     # Source code functions
     ##########################################################################
 
-    def _generate_algebraic_modules_source_code(self, *, include_meta_info: bool = True) -> Tuple[str, str]:
+    def _generate_algebraic_modules_source_code(
+        self, *, include_meta_info: bool = True
+    ) -> Tuple[str, str]:
         """Generate modelbase source code for algebraic modules.
 
         This is mainly used for the generate_model_source_code function.
