@@ -89,7 +89,11 @@ class _IntegratorScipy(AbstractIntegrator):
         else:
             raise ValueError("You need to supply t_end (+steps) or time_points")
         y = spi.odeint(
-            func=self.rhs, y0=self.y0, t=t_array, tfirst=True, **{**self.kwargs, **integrator_kwargs}
+            func=self.rhs,
+            y0=self.y0,
+            t=t_array,
+            tfirst=True,
+            **{**self.kwargs, **integrator_kwargs},
         )
         self.t0 = t_array[-1]
         self.y0 = y[-1, :]
