@@ -103,7 +103,9 @@ class Model(_AbstractRateModel, BaseModel):
     ) -> Optional[Union[List[str], Dict[str, List[str]]]]:
         self_collection = getattr(self, attribute)
         other_collection = getattr(other, attribute)
-        intersection: List[str] = sorted(set(self_collection).intersection(other_collection))
+        intersection: List[str] = sorted(
+            set(self_collection).intersection(other_collection)
+        )
         if not intersection:
             return None
         if attribute == "compounds":
@@ -386,6 +388,16 @@ class Model(_AbstractRateModel, BaseModel):
         for rate_name, reaction in reactions.items():
             self.update_reaction(rate_name, **reaction)
 
+    def update_reaction_from_args(
+        self,
+        rate_name: str,
+        stoichiometry: Dict[str, float] | None = None,
+        args: List[str] | None = None,
+        reversible: bool | None = None,
+        check_consistency: bool = True,
+    ) -> None:
+        raise NotImplementedError
+
     def add_reaction_from_ratelaw(
         self,
         rate_name: str,
@@ -517,7 +529,9 @@ class Model(_AbstractRateModel, BaseModel):
     # Model conversion functions
     ##########################################################################
 
-    def to_labelmodel(self, labelcompounds: Dict[str, int], labelmaps: Dict[str, List[int]]) -> LabelModel:
+    def to_labelmodel(
+        self, labelcompounds: Dict[str, int], labelmaps: Dict[str, List[int]]
+    ) -> LabelModel:
         """Create a LabelModel from this model.
 
         Examples
@@ -541,7 +555,9 @@ class Model(_AbstractRateModel, BaseModel):
         lm.add_parameters(self.parameters)
         for compound in self.get_compounds():
             if compound in labelcompounds:
-                lm.add_label_compound(compound=compound, num_labels=labelcompounds[compound])
+                lm.add_label_compound(
+                    compound=compound, num_labels=labelcompounds[compound]
+                )
             else:
                 lm.add_compound(compound=compound)
 
@@ -623,7 +639,9 @@ class Model(_AbstractRateModel, BaseModel):
                     rate_name=rate_name,
                     stoichiometry={
                         k: v
-                        for k, v in cast(Dict[str, int], self.stoichiometries[rate_name]).items()
+                        for k, v in cast(
+                            Dict[str, int], self.stoichiometries[rate_name]
+                        ).items()
                         if k in labelcompounds
                     },
                     labelmap=labelmaps[rate_name],
@@ -636,7 +654,9 @@ class Model(_AbstractRateModel, BaseModel):
     # Source code functions
     ##########################################################################
 
-    def generate_model_source_code(self, linted: bool = True, include_meta_info: bool = False) -> str:
+    def generate_model_source_code(
+        self, linted: bool = True, include_meta_info: bool = False
+    ) -> str:
         """Generate source code of the model.
 
         Parameters
@@ -650,12 +670,16 @@ class Model(_AbstractRateModel, BaseModel):
         parameters, par_fns, derived_pars = self._generate_parameters_source_code(
             include_meta_info=include_meta_info
         )
-        compounds = self._generate_compounds_source_code(include_meta_info=include_meta_info)
+        compounds = self._generate_compounds_source_code(
+            include_meta_info=include_meta_info
+        )
         functions = self._generate_function_source_code()
         module_functions, modules = self._generate_algebraic_modules_source_code(
             include_meta_info=include_meta_info
         )
-        rate_functions, rates = self._generate_rates_source_code(include_meta_info=include_meta_info)
+        rate_functions, rates = self._generate_rates_source_code(
+            include_meta_info=include_meta_info
+        )
         stoichiometries = self._generate_stoichiometries_source_code()
 
         to_export = [
@@ -685,7 +709,9 @@ class Model(_AbstractRateModel, BaseModel):
 
         model_string = "\n".join(to_export)
         if linted:
-            blacked_string = subprocess.run(["black", "-c", model_string], stdout=subprocess.PIPE, check=True)
+            blacked_string = subprocess.run(
+                ["black", "-c", model_string], stdout=subprocess.PIPE, check=True
+            )
             return blacked_string.stdout.decode("utf-8")
         return model_string
 
